@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.32 2006/01/09 16:30:20 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/graphics.c,v 1.36 2006/08/09 16:54:01 richb Exp $
  *
  *  Copyright (c) 1987-2006 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -26,7 +26,7 @@
 #include "extern.h"
 #include "ce_parser.h"
 #include "lr_parser.h"
-
+#include "functions.h"
 
 /* Process menu selection. */
 
@@ -34,15 +34,23 @@ void
 handle_menu_selection(struct button *n, int item)
 {
     if (item != -1) {    
-        save_pending_values(n);
-        if (v->current != NULL) {
+        struct exprm_state *e;
+
+	save_pending_values(n);
+	if (v->current != NULL) {
 	    free(v->current);
-        }
-        v->current = copy_button_info(button_for_value(item));
-        v->ismenu = 1;       /* To prevent grey buttons being redrawn. */
-        do_pending();
-        v->ismenu = 0;
-        v->down = 0;
+	}
+
+	e = get_state();
+	memcpy(&(e->button), button_for_value(item), sizeof(struct button));
+	new_state();
+	
+	v->ismenu = 1;       /* To prevent grey buttons being redrawn. */
+	do_pending();
+	v->ismenu = 0;
+	v->down = 0;
+	
+	v->current = copy_button_info(button_for_value(item));
     }
 }
 
@@ -50,7 +58,6 @@ handle_menu_selection(struct button *n, int item)
 void
 make_registers()            /* Calculate memory register frame values. */
 {
-    char line[MAXLINE];     /* Current memory register line. */
     char *mval;
     int n;
 
